pub enum RealtimeBetaResponseCreateParamsToolChoice {
Options(ToolChoiceOptions),
Function(ToolChoiceFunction),
Mcp(ToolChoiceMcp),
}Expand description
How the model chooses tools. Provide one of the string modes or force a specific function/MCP tool.
JSON schema
{
"description": "How the model chooses tools. Provide one of the string modes or force a specific\nfunction/MCP tool.\n",
"oneOf": [
{
"$ref": "#/components/schemas/ToolChoiceOptions"
},
{
"$ref": "#/components/schemas/ToolChoiceFunction"
},
{
"$ref": "#/components/schemas/ToolChoiceMCP"
}
]
}Variants