pub enum ResponsePromptCacheRetention {
InMemory,
X24h,
}Expand description
ResponsePromptCacheRetention
JSON schema
{
"anyOf": [
{
"description": "The retention policy for the prompt cache. Set to `24h` to enable extended prompt caching, which keeps cached prefixes active for longer, up to a maximum of 24 hours. [Learn more](/docs/guides/prompt-caching#prompt-cache-retention).\n",
"type": "string",
"enum": [
"in_memory",
"24h"
]
}
]
}Variants
InMemory
The retention policy for the prompt cache. Set to 24h to enable extended prompt caching, which keeps cached prefixes active for longer, up to a maximum of 24 hours. Learn more.
X24h
The retention policy for the prompt cache. Set to 24h to enable extended prompt caching, which keeps cached prefixes active for longer, up to a maximum of 24 hours. Learn more.