TextResponseFormatConfiguration

Enum TextResponseFormatConfiguration 

pub enum TextResponseFormatConfiguration {
    ResponseFormatText(ResponseFormatText),
    TextResponseFormatJsonSchema(TextResponseFormatJsonSchema),
    ResponseFormatJsonObject(ResponseFormatJsonObject),
}
An object specifying the format that the model must output.

Configuring { "type": "json_schema" } enables Structured Outputs, which ensures the model will match your supplied JSON schema. Learn more in the Structured Outputs guide.

The default format is { "type": "text" } with no additional options.

Not recommended for gpt-4o and newer models:

Setting to { "type": "json_object" } enables the older JSON mode, which ensures the message the model generates is valid JSON. Using json_schema is preferred for models that support it.

JSON schema
{
 "description": "An object specifying the format that the model must output.\n\nConfiguring `{ \"type\": \"json_schema\" }` enables Structured Outputs, \nwhich ensures the model will match your supplied JSON schema. Learn more in the \n[Structured Outputs guide](/docs/guides/structured-outputs).\n\nThe default format is `{ \"type\": \"text\" }` with no additional options.\n\n**Not recommended for gpt-4o and newer models:**\n\nSetting to `{ \"type\": \"json_object\" }` enables the older JSON mode, which\nensures the message the model generates is valid JSON. Using `json_schema`\nis preferred for models that support it.\n",
 "oneOf": [
   {
     "$ref": "#/components/schemas/ResponseFormatText"
   },
   {
     "$ref": "#/components/schemas/TextResponseFormatJsonSchema"
   },
   {
     "$ref": "#/components/schemas/ResponseFormatJsonObject"
   }
 ]
}

Variants



ResponseFormatText(ResponseFormatText)



TextResponseFormatJsonSchema(TextResponseFormatJsonSchema)



ResponseFormatJsonObject(ResponseFormatJsonObject)