pub enum ToolChoiceOptions {
None,
Auto,
Required,
}Expand description
Controls which (if any) tool is called by the model.
none means the model will not call any tool and instead generates a message.
auto means the model can pick between generating a message or calling one or
more tools.
required means the model must call one or more tools.
JSON schema
{
"title": "Tool choice mode",
"description": "Controls which (if any) tool is called by the model.\n\n`none` means the model will not call any tool and instead generates a message.\n\n`auto` means the model can pick between generating a message or calling one or\nmore tools.\n\n`required` means the model must call one or more tools.\n",
"type": "string",
"enum": [
"none",
"auto",
"required"
]
}Variants