pub struct FilePath {
pub file_id: String,
pub index: i64,
pub type_: FilePathType,
}Expand description
A path to a file.
JSON schema
{
"title": "File path",
"description": "A path to a file.\n",
"type": "object",
"required": [
"file_id",
"index",
"type"
],
"properties": {
"file_id": {
"description": "The ID of the file.\n",
"type": "string"
},
"index": {
"description": "The index of the file in the list of files.\n",
"type": "integer"
},
"type": {
"description": "The type of the file path. Always `file_path`.\n",
"type": "string",
"enum": [
"file_path"
],
"x-stainless-const": true
}
}
}Fields
file_id: StringThe ID of the file.
index: i64The index of the file in the list of files.
type_: FilePathTypeThe type of the file path. Always file_path.