pub struct InputImageContent {
pub detail: ImageDetail,
pub file_id: Option<String>,
pub image_url: Option<String>,
pub type_: InputImageContentType,
}Expand description
An image input to the model. Learn about image inputs.
JSON schema
{
"title": "Input image",
"description": "An image input to the model. Learn about [image inputs](/docs/guides/vision).",
"type": "object",
"required": [
"detail",
"type"
],
"properties": {
"detail": {
"$ref": "#/components/schemas/ImageDetail"
},
"file_id": {
"anyOf": [
{
"description": "The ID of the file to be sent to the model.",
"type": "string"
}
]
},
"image_url": {
"anyOf": [
{
"description": "The URL of the image to be sent to the model. A fully qualified URL or base64 encoded image in a data URL.",
"type": "string",
"format": "uri"
}
]
},
"type": {
"description": "The type of the input item. Always `input_image`.",
"type": "string",
"enum": [
"input_image"
],
"x-stainless-const": true
}
}
}Fields
detail: ImageDetailfile_id: Option<String>image_url: Option<String>type_: InputImageContentTypeThe type of the input item. Always input_image.