pub struct Prompt {
pub id: String,
pub variables: Option<ResponsePromptVariables>,
pub version: Option<String>,
}Expand description
Reference to a prompt template and its variables. Learn more.
JSON schema
{
"description": "Reference to a prompt template and its variables.\n[Learn more](/docs/guides/text?api-mode=responses#reusable-prompts).\n",
"type": "object",
"required": [
"id"
],
"properties": {
"id": {
"description": "The unique identifier of the prompt template to use.",
"type": "string"
},
"variables": {
"$ref": "#/components/schemas/ResponsePromptVariables"
},
"version": {
"anyOf": [
{
"description": "Optional version of the prompt template.",
"type": "string"
}
]
}
}
}Fields
id: StringThe unique identifier of the prompt template to use.
variables: Option<ResponsePromptVariables>version: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Prompt
impl<'de> Deserialize<'de> for Prompt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more