Reasoning

Struct Reasoning 

pub struct Reasoning {
    pub effort: Option<ReasoningEffort>,
    pub generate_summary: Option<ReasoningGenerateSummary>,
    pub summary: Option<ReasoningSummary>,
}
gpt-5 and o-series models only

Configuration options for reasoning models.

JSON schema
{
 "title": "Reasoning",
 "description": "**gpt-5 and o-series models only**\n\nConfiguration options for\n[reasoning models](https://platform.openai.com/docs/guides/reasoning).\n",
 "type": "object",
 "properties": {
   "effort": {
     "$ref": "#/components/schemas/ReasoningEffort"
   },
   "generate_summary": {
     "anyOf": [
       {
         "description": "**Deprecated:** use `summary` instead.\n\nA summary of the reasoning performed by the model. This can be\nuseful for debugging and understanding the model's reasoning process.\nOne of `auto`, `concise`, or `detailed`.\n",
         "deprecated": true,
         "type": "string",
         "enum": [
           "auto",
           "concise",
           "detailed"
         ]
       }
     ]
   },
   "summary": {
     "anyOf": [
       {
         "description": "A summary of the reasoning performed by the model. This can be\nuseful for debugging and understanding the model's reasoning process.\nOne of `auto`, `concise`, or `detailed`.\n\n`concise` is supported for `computer-use-preview` models and all reasoning models after `gpt-5`.\n",
         "type": "string",
         "enum": [
           "auto",
           "concise",
           "detailed"
         ]
       }
     ]
   }
 }
}

Fields

effort: Option<ReasoningEffort>generate_summary: Option<ReasoningGenerateSummary>summary: Option<ReasoningSummary>