pub struct ResponseCodeInterpreterCallCompletedEvent {
pub item_id: String,
pub output_index: i64,
pub sequence_number: i64,
pub type_: ResponseCodeInterpreterCallCompletedEventType,
}Expand description
Emitted when the code interpreter call is completed.
JSON schema
{
"description": "Emitted when the code interpreter call is completed.",
"type": "object",
"required": [
"item_id",
"output_index",
"sequence_number",
"type"
],
"properties": {
"item_id": {
"description": "The unique identifier of the code interpreter tool call item.",
"type": "string"
},
"output_index": {
"description": "The index of the output item in the response for which the code interpreter call is completed.",
"type": "integer"
},
"sequence_number": {
"description": "The sequence number of this event, used to order streaming events.",
"type": "integer"
},
"type": {
"description": "The type of the event. Always `response.code_interpreter_call.completed`.",
"type": "string",
"enum": [
"response.code_interpreter_call.completed"
],
"x-stainless-const": true
}
},
"x-oaiMeta": {
"group": "responses",
"name": "response.code_interpreter_call.completed"
}
}Fields
item_id: StringThe unique identifier of the code interpreter tool call item.
output_index: i64The index of the output item in the response for which the code interpreter call is completed.
sequence_number: i64The sequence number of this event, used to order streaming events.
type_: ResponseCodeInterpreterCallCompletedEventTypeThe type of the event. Always response.code_interpreter_call.completed.