pub struct ResponseContentPartDoneEvent {
pub content_index: i64,
pub item_id: String,
pub output_index: i64,
pub part: OutputContent,
pub sequence_number: i64,
pub type_: ResponseContentPartDoneEventType,
}Expand description
Emitted when a content part is done.
JSON schema
{
"description": "Emitted when a content part is done.",
"type": "object",
"required": [
"content_index",
"item_id",
"output_index",
"part",
"sequence_number",
"type"
],
"properties": {
"content_index": {
"description": "The index of the content part that is done.\n",
"type": "integer"
},
"item_id": {
"description": "The ID of the output item that the content part was added to.\n",
"type": "string"
},
"output_index": {
"description": "The index of the output item that the content part was added to.\n",
"type": "integer"
},
"part": {
"$ref": "#/components/schemas/OutputContent"
},
"sequence_number": {
"description": "The sequence number of this event.",
"type": "integer"
},
"type": {
"description": "The type of the event. Always `response.content_part.done`.\n",
"type": "string",
"enum": [
"response.content_part.done"
],
"x-stainless-const": true
}
},
"x-oaiMeta": {
"group": "responses",
"name": "response.content_part.done"
}
}Fields
content_index: i64The index of the content part that is done.
item_id: StringThe ID of the output item that the content part was added to.
output_index: i64The index of the output item that the content part was added to.
part: OutputContentsequence_number: i64The sequence number of this event.
type_: ResponseContentPartDoneEventTypeThe type of the event. Always response.content_part.done.