pub struct ResponseCustomToolCallInputDeltaEvent {
pub delta: String,
pub item_id: String,
pub output_index: i64,
pub sequence_number: i64,
pub type_: ResponseCustomToolCallInputDeltaEventType,
}Expand description
Event representing a delta (partial update) to the input of a custom tool call.
JSON schema
{
"title": "ResponseCustomToolCallInputDelta",
"description": "Event representing a delta (partial update) to the input of a custom tool call.\n",
"type": "object",
"required": [
"delta",
"item_id",
"output_index",
"sequence_number",
"type"
],
"properties": {
"delta": {
"description": "The incremental input data (delta) for the custom tool call.",
"type": "string"
},
"item_id": {
"description": "Unique identifier for the API item associated with this event.",
"type": "string"
},
"output_index": {
"description": "The index of the output this delta applies to.",
"type": "integer"
},
"sequence_number": {
"description": "The sequence number of this event.",
"type": "integer"
},
"type": {
"description": "The event type identifier.",
"type": "string",
"enum": [
"response.custom_tool_call_input.delta"
],
"x-stainless-const": true
}
},
"x-oaiMeta": {
"group": "responses",
"name": "response.custom_tool_call_input.delta"
}
}Fields
delta: StringThe incremental input data (delta) for the custom tool call.
item_id: StringUnique identifier for the API item associated with this event.
output_index: i64The index of the output this delta applies to.
sequence_number: i64The sequence number of this event.
type_: ResponseCustomToolCallInputDeltaEventTypeThe event type identifier.