pub struct ResponseFileSearchCallSearchingEvent {
pub item_id: String,
pub output_index: i64,
pub sequence_number: i64,
pub type_: ResponseFileSearchCallSearchingEventType,
}Expand description
Emitted when a file search is currently searching.
JSON schema
{
"description": "Emitted when a file search is currently searching.",
"type": "object",
"required": [
"item_id",
"output_index",
"sequence_number",
"type"
],
"properties": {
"item_id": {
"description": "The ID of the output item that the file search call is initiated.\n",
"type": "string"
},
"output_index": {
"description": "The index of the output item that the file search call is searching.\n",
"type": "integer"
},
"sequence_number": {
"description": "The sequence number of this event.",
"type": "integer"
},
"type": {
"description": "The type of the event. Always `response.file_search_call.searching`.\n",
"type": "string",
"enum": [
"response.file_search_call.searching"
],
"x-stainless-const": true
}
},
"x-oaiMeta": {
"group": "responses",
"name": "response.file_search_call.searching"
}
}Fields
item_id: StringThe ID of the output item that the file search call is initiated.
output_index: i64The index of the output item that the file search call is searching.
sequence_number: i64The sequence number of this event.
type_: ResponseFileSearchCallSearchingEventTypeThe type of the event. Always response.file_search_call.searching.