pub struct ResponseFunctionCallArgumentsDeltaEvent {
pub delta: String,
pub item_id: String,
pub output_index: i64,
pub sequence_number: i64,
pub type_: ResponseFunctionCallArgumentsDeltaEventType,
}Expand description
Emitted when there is a partial function-call arguments delta.
JSON schema
{
"description": "Emitted when there is a partial function-call arguments delta.",
"type": "object",
"required": [
"delta",
"item_id",
"output_index",
"sequence_number",
"type"
],
"properties": {
"delta": {
"description": "The function-call arguments delta that is added.\n",
"type": "string"
},
"item_id": {
"description": "The ID of the output item that the function-call arguments delta is added to.\n",
"type": "string"
},
"output_index": {
"description": "The index of the output item that the function-call arguments delta is added to.\n",
"type": "integer"
},
"sequence_number": {
"description": "The sequence number of this event.",
"type": "integer"
},
"type": {
"description": "The type of the event. Always `response.function_call_arguments.delta`.\n",
"type": "string",
"enum": [
"response.function_call_arguments.delta"
],
"x-stainless-const": true
}
},
"x-oaiMeta": {
"group": "responses",
"name": "response.function_call_arguments.delta"
}
}Fields
delta: StringThe function-call arguments delta that is added.
item_id: StringThe ID of the output item that the function-call arguments delta is added to.
output_index: i64The index of the output item that the function-call arguments delta is added to.
sequence_number: i64The sequence number of this event.
type_: ResponseFunctionCallArgumentsDeltaEventTypeThe type of the event. Always response.function_call_arguments.delta.