pub struct ResponseImageGenCallCompletedEvent {
pub item_id: String,
pub output_index: i64,
pub sequence_number: i64,
pub type_: ResponseImageGenCallCompletedEventType,
}Expand description
Emitted when an image generation tool call has completed and the final image is available.
JSON schema
{
"title": "ResponseImageGenCallCompletedEvent",
"description": "Emitted when an image generation tool call has completed and the final image is available.\n",
"type": "object",
"required": [
"item_id",
"output_index",
"sequence_number",
"type"
],
"properties": {
"item_id": {
"description": "The unique identifier of the image generation item being processed.",
"type": "string"
},
"output_index": {
"description": "The index of the output item in the response's output array.",
"type": "integer"
},
"sequence_number": {
"description": "The sequence number of this event.",
"type": "integer"
},
"type": {
"description": "The type of the event. Always 'response.image_generation_call.completed'.",
"type": "string",
"enum": [
"response.image_generation_call.completed"
],
"x-stainless-const": true
}
},
"x-oaiMeta": {
"group": "responses",
"name": "response.image_generation_call.completed"
}
}Fields
item_id: StringThe unique identifier of the image generation item being processed.
output_index: i64The index of the output item in the response’s output array.
sequence_number: i64The sequence number of this event.
type_: ResponseImageGenCallCompletedEventTypeThe type of the event. Always ‘response.image_generation_call.completed’.