pub struct ResponseLogProb {
pub logprob: f64,
pub token: String,
pub top_logprobs: Vec<ResponseLogProbTopLogprobsItem>,
}Expand description
A logprob is the logarithmic probability that the model assigns to producing a particular token at a given position in the sequence. Less-negative (higher) logprob values indicate greater model confidence in that token choice.
JSON schema
{
"description": "A logprob is the logarithmic probability that the model assigns to producing \na particular token at a given position in the sequence. Less-negative (higher) \nlogprob values indicate greater model confidence in that token choice.\n",
"type": "object",
"required": [
"logprob",
"token"
],
"properties": {
"logprob": {
"description": "The log probability of this token.\n",
"type": "number"
},
"token": {
"description": "A possible text token.",
"type": "string"
},
"top_logprobs": {
"description": "The log probabilities of up to 20 of the most likely tokens.\n",
"type": "array",
"items": {
"type": "object",
"properties": {
"logprob": {
"description": "The log probability of this token.",
"type": "number"
},
"token": {
"description": "A possible text token.",
"type": "string"
}
}
}
}
}
}Fields
logprob: f64The log probability of this token.
token: StringA possible text token.
top_logprobs: Vec<ResponseLogProbTopLogprobsItem>The log probabilities of up to 20 of the most likely tokens.