pub struct ResponseMcpCallArgumentsDeltaEvent {
pub delta: String,
pub item_id: String,
pub output_index: i64,
pub sequence_number: i64,
pub type_: ResponseMcpCallArgumentsDeltaEventType,
}Expand description
Emitted when there is a delta (partial update) to the arguments of an MCP tool call.
JSON schema
{
"title": "ResponseMCPCallArgumentsDeltaEvent",
"description": "Emitted when there is a delta (partial update) to the arguments of an MCP tool call.\n",
"type": "object",
"required": [
"delta",
"item_id",
"output_index",
"sequence_number",
"type"
],
"properties": {
"delta": {
"description": "A JSON string containing the partial update to the arguments for the MCP tool call.\n",
"type": "string"
},
"item_id": {
"description": "The unique identifier of the MCP tool call item being processed.",
"type": "string"
},
"output_index": {
"description": "The index of the output item in the response's output array.",
"type": "integer"
},
"sequence_number": {
"description": "The sequence number of this event.",
"type": "integer"
},
"type": {
"description": "The type of the event. Always 'response.mcp_call_arguments.delta'.",
"type": "string",
"enum": [
"response.mcp_call_arguments.delta"
],
"x-stainless-const": true
}
},
"x-oaiMeta": {
"group": "responses",
"name": "response.mcp_call_arguments.delta"
}
}Fields
delta: StringA JSON string containing the partial update to the arguments for the MCP tool call.
item_id: StringThe unique identifier of the MCP tool call item being processed.
output_index: i64The index of the output item in the response’s output array.
sequence_number: i64The sequence number of this event.
type_: ResponseMcpCallArgumentsDeltaEventTypeThe type of the event. Always ‘response.mcp_call_arguments.delta’.