pub struct ResponseMcpCallArgumentsDoneEvent {
pub arguments: String,
pub item_id: String,
pub output_index: i64,
pub sequence_number: i64,
pub type_: ResponseMcpCallArgumentsDoneEventType,
}Expand description
Emitted when the arguments for an MCP tool call are finalized.
JSON schema
{
"title": "ResponseMCPCallArgumentsDoneEvent",
"description": "Emitted when the arguments for an MCP tool call are finalized.\n",
"type": "object",
"required": [
"arguments",
"item_id",
"output_index",
"sequence_number",
"type"
],
"properties": {
"arguments": {
"description": "A JSON string containing the finalized arguments for the MCP tool call.\n",
"type": "string"
},
"item_id": {
"description": "The unique identifier of the MCP tool call item being processed.",
"type": "string"
},
"output_index": {
"description": "The index of the output item in the response's output array.",
"type": "integer"
},
"sequence_number": {
"description": "The sequence number of this event.",
"type": "integer"
},
"type": {
"description": "The type of the event. Always 'response.mcp_call_arguments.done'.",
"type": "string",
"enum": [
"response.mcp_call_arguments.done"
],
"x-stainless-const": true
}
},
"x-oaiMeta": {
"group": "responses",
"name": "response.mcp_call_arguments.done"
}
}Fields
arguments: StringA JSON string containing the finalized arguments for the MCP tool call.
item_id: StringThe unique identifier of the MCP tool call item being processed.
output_index: i64The index of the output item in the response’s output array.
sequence_number: i64The sequence number of this event.
type_: ResponseMcpCallArgumentsDoneEventTypeThe type of the event. Always ‘response.mcp_call_arguments.done’.