pub struct ResponseMcpCallInProgressEvent {
pub item_id: String,
pub output_index: i64,
pub sequence_number: i64,
pub type_: ResponseMcpCallInProgressEventType,
}Expand description
Emitted when an MCP tool call is in progress.
JSON schema
{
"title": "ResponseMCPCallInProgressEvent",
"description": "Emitted when an MCP tool call is in progress.\n",
"type": "object",
"required": [
"item_id",
"output_index",
"sequence_number",
"type"
],
"properties": {
"item_id": {
"description": "The unique identifier of the MCP tool call item being processed.",
"type": "string"
},
"output_index": {
"description": "The index of the output item in the response's output array.",
"type": "integer"
},
"sequence_number": {
"description": "The sequence number of this event.",
"type": "integer"
},
"type": {
"description": "The type of the event. Always 'response.mcp_call.in_progress'.",
"type": "string",
"enum": [
"response.mcp_call.in_progress"
],
"x-stainless-const": true
}
},
"x-oaiMeta": {
"group": "responses",
"name": "response.mcp_call.in_progress"
}
}Fields
item_id: StringThe unique identifier of the MCP tool call item being processed.
output_index: i64The index of the output item in the response’s output array.
sequence_number: i64The sequence number of this event.
type_: ResponseMcpCallInProgressEventTypeThe type of the event. Always ‘response.mcp_call.in_progress’.