pub struct ResponseReasoningSummaryPartAddedEvent {
pub item_id: String,
pub output_index: i64,
pub part: ResponseReasoningSummaryPartAddedEventPart,
pub sequence_number: i64,
pub summary_index: i64,
pub type_: ResponseReasoningSummaryPartAddedEventType,
}Expand description
Emitted when a new reasoning summary part is added.
JSON schema
{
"description": "Emitted when a new reasoning summary part is added.",
"type": "object",
"required": [
"item_id",
"output_index",
"part",
"sequence_number",
"summary_index",
"type"
],
"properties": {
"item_id": {
"description": "The ID of the item this summary part is associated with.\n",
"type": "string"
},
"output_index": {
"description": "The index of the output item this summary part is associated with.\n",
"type": "integer"
},
"part": {
"description": "The summary part that was added.\n",
"type": "object",
"required": [
"text",
"type"
],
"properties": {
"text": {
"description": "The text of the summary part.",
"type": "string"
},
"type": {
"description": "The type of the summary part. Always `summary_text`.",
"type": "string",
"enum": [
"summary_text"
],
"x-stainless-const": true
}
}
},
"sequence_number": {
"description": "The sequence number of this event.\n",
"type": "integer"
},
"summary_index": {
"description": "The index of the summary part within the reasoning summary.\n",
"type": "integer"
},
"type": {
"description": "The type of the event. Always `response.reasoning_summary_part.added`.\n",
"type": "string",
"enum": [
"response.reasoning_summary_part.added"
],
"x-stainless-const": true
}
},
"x-oaiMeta": {
"group": "responses",
"name": "response.reasoning_summary_part.added"
}
}Fields
item_id: StringThe ID of the item this summary part is associated with.
output_index: i64The index of the output item this summary part is associated with.
part: ResponseReasoningSummaryPartAddedEventPartsequence_number: i64The sequence number of this event.
summary_index: i64The index of the summary part within the reasoning summary.
type_: ResponseReasoningSummaryPartAddedEventTypeThe type of the event. Always response.reasoning_summary_part.added.