pub struct ResponseReasoningSummaryTextDeltaEvent {
pub delta: String,
pub item_id: String,
pub output_index: i64,
pub sequence_number: i64,
pub summary_index: i64,
pub type_: ResponseReasoningSummaryTextDeltaEventType,
}Expand description
Emitted when a delta is added to a reasoning summary text.
JSON schema
{
"description": "Emitted when a delta is added to a reasoning summary text.",
"type": "object",
"required": [
"delta",
"item_id",
"output_index",
"sequence_number",
"summary_index",
"type"
],
"properties": {
"delta": {
"description": "The text delta that was added to the summary.\n",
"type": "string"
},
"item_id": {
"description": "The ID of the item this summary text delta is associated with.\n",
"type": "string"
},
"output_index": {
"description": "The index of the output item this summary text delta is associated with.\n",
"type": "integer"
},
"sequence_number": {
"description": "The sequence number of this event.\n",
"type": "integer"
},
"summary_index": {
"description": "The index of the summary part within the reasoning summary.\n",
"type": "integer"
},
"type": {
"description": "The type of the event. Always `response.reasoning_summary_text.delta`.\n",
"type": "string",
"enum": [
"response.reasoning_summary_text.delta"
],
"x-stainless-const": true
}
},
"x-oaiMeta": {
"group": "responses",
"name": "response.reasoning_summary_text.delta"
}
}Fields
delta: StringThe text delta that was added to the summary.
item_id: StringThe ID of the item this summary text delta is associated with.
output_index: i64The index of the output item this summary text delta is associated with.
sequence_number: i64The sequence number of this event.
summary_index: i64The index of the summary part within the reasoning summary.
type_: ResponseReasoningSummaryTextDeltaEventTypeThe type of the event. Always response.reasoning_summary_text.delta.