pub struct ResponseReasoningTextDeltaEvent {
pub content_index: i64,
pub delta: String,
pub item_id: String,
pub output_index: i64,
pub sequence_number: i64,
pub type_: ResponseReasoningTextDeltaEventType,
}Expand description
Emitted when a delta is added to a reasoning text.
JSON schema
{
"description": "Emitted when a delta is added to a reasoning text.",
"type": "object",
"required": [
"content_index",
"delta",
"item_id",
"output_index",
"sequence_number",
"type"
],
"properties": {
"content_index": {
"description": "The index of the reasoning content part this delta is associated with.\n",
"type": "integer"
},
"delta": {
"description": "The text delta that was added to the reasoning content.\n",
"type": "string"
},
"item_id": {
"description": "The ID of the item this reasoning text delta is associated with.\n",
"type": "string"
},
"output_index": {
"description": "The index of the output item this reasoning text delta is associated with.\n",
"type": "integer"
},
"sequence_number": {
"description": "The sequence number of this event.\n",
"type": "integer"
},
"type": {
"description": "The type of the event. Always `response.reasoning_text.delta`.\n",
"type": "string",
"enum": [
"response.reasoning_text.delta"
],
"x-stainless-const": true
}
},
"x-oaiMeta": {
"group": "responses",
"name": "response.reasoning_text.delta"
}
}Fields
content_index: i64The index of the reasoning content part this delta is associated with.
delta: StringThe text delta that was added to the reasoning content.
item_id: StringThe ID of the item this reasoning text delta is associated with.
output_index: i64The index of the output item this reasoning text delta is associated with.
sequence_number: i64The sequence number of this event.
type_: ResponseReasoningTextDeltaEventTypeThe type of the event. Always response.reasoning_text.delta.