pub struct ResponseReasoningTextDoneEvent {
pub content_index: i64,
pub item_id: String,
pub output_index: i64,
pub sequence_number: i64,
pub text: String,
pub type_: ResponseReasoningTextDoneEventType,
}Expand description
Emitted when a reasoning text is completed.
JSON schema
{
"description": "Emitted when a reasoning text is completed.",
"type": "object",
"required": [
"content_index",
"item_id",
"output_index",
"sequence_number",
"text",
"type"
],
"properties": {
"content_index": {
"description": "The index of the reasoning content part.\n",
"type": "integer"
},
"item_id": {
"description": "The ID of the item this reasoning text is associated with.\n",
"type": "string"
},
"output_index": {
"description": "The index of the output item this reasoning text is associated with.\n",
"type": "integer"
},
"sequence_number": {
"description": "The sequence number of this event.\n",
"type": "integer"
},
"text": {
"description": "The full text of the completed reasoning content.\n",
"type": "string"
},
"type": {
"description": "The type of the event. Always `response.reasoning_text.done`.\n",
"type": "string",
"enum": [
"response.reasoning_text.done"
],
"x-stainless-const": true
}
},
"x-oaiMeta": {
"group": "responses",
"name": "response.reasoning_text.done"
}
}Fields
content_index: i64The index of the reasoning content part.
item_id: StringThe ID of the item this reasoning text is associated with.
output_index: i64The index of the output item this reasoning text is associated with.
sequence_number: i64The sequence number of this event.
text: StringThe full text of the completed reasoning content.
type_: ResponseReasoningTextDoneEventTypeThe type of the event. Always response.reasoning_text.done.