pub struct ResponseTextDeltaEvent {
pub content_index: i64,
pub delta: String,
pub item_id: String,
pub logprobs: Vec<ResponseLogProb>,
pub output_index: i64,
pub sequence_number: i64,
pub type_: ResponseTextDeltaEventType,
}Expand description
Emitted when there is an additional text delta.
JSON schema
{
"description": "Emitted when there is an additional text delta.",
"type": "object",
"required": [
"content_index",
"delta",
"item_id",
"logprobs",
"output_index",
"sequence_number",
"type"
],
"properties": {
"content_index": {
"description": "The index of the content part that the text delta was added to.\n",
"type": "integer"
},
"delta": {
"description": "The text delta that was added.\n",
"type": "string"
},
"item_id": {
"description": "The ID of the output item that the text delta was added to.\n",
"type": "string"
},
"logprobs": {
"description": "The log probabilities of the tokens in the delta.\n",
"type": "array",
"items": {
"$ref": "#/components/schemas/ResponseLogProb"
}
},
"output_index": {
"description": "The index of the output item that the text delta was added to.\n",
"type": "integer"
},
"sequence_number": {
"description": "The sequence number for this event.",
"type": "integer"
},
"type": {
"description": "The type of the event. Always `response.output_text.delta`.\n",
"type": "string",
"enum": [
"response.output_text.delta"
],
"x-stainless-const": true
}
},
"x-oaiMeta": {
"group": "responses",
"name": "response.output_text.delta"
}
}Fields
content_index: i64The index of the content part that the text delta was added to.
delta: StringThe text delta that was added.
item_id: StringThe ID of the output item that the text delta was added to.
logprobs: Vec<ResponseLogProb>The log probabilities of the tokens in the delta.
output_index: i64The index of the output item that the text delta was added to.
sequence_number: i64The sequence number for this event.
type_: ResponseTextDeltaEventTypeThe type of the event. Always response.output_text.delta.