pub struct ResponseTextParam {
pub format: Option<TextResponseFormatConfiguration>,
pub verbosity: Option<Verbosity>,
}Expand description
Configuration options for a text response from the model. Can be plain text or structured JSON data. Learn more:
JSON schema
{
"description": "Configuration options for a text response from the model. Can be plain\ntext or structured JSON data. Learn more:\n- [Text inputs and outputs](/docs/guides/text)\n- [Structured Outputs](/docs/guides/structured-outputs)\n",
"type": "object",
"properties": {
"format": {
"$ref": "#/components/schemas/TextResponseFormatConfiguration"
},
"verbosity": {
"$ref": "#/components/schemas/Verbosity"
}
}
}Fields
format: Option<TextResponseFormatConfiguration>verbosity: Option<Verbosity>Trait Implementations
Sourceimpl Clone for ResponseTextParam
impl Clone for ResponseTextParam
Sourcefn clone(&self) -> ResponseTextParam
fn clone(&self) -> ResponseTextParam
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResponseTextParam
impl Debug for ResponseTextParam
Sourceimpl Default for ResponseTextParam
impl Default for ResponseTextParam
Sourceimpl<'de> Deserialize<'de> for ResponseTextParam
impl<'de> Deserialize<'de> for ResponseTextParam
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more