pub struct ResponseWebSearchCallInProgressEvent {
pub item_id: String,
pub output_index: i64,
pub sequence_number: i64,
pub type_: ResponseWebSearchCallInProgressEventType,
}Expand description
Emitted when a web search call is initiated.
JSON schema
{
"description": "Emitted when a web search call is initiated.",
"type": "object",
"required": [
"item_id",
"output_index",
"sequence_number",
"type"
],
"properties": {
"item_id": {
"description": "Unique ID for the output item associated with the web search call.\n",
"type": "string"
},
"output_index": {
"description": "The index of the output item that the web search call is associated with.\n",
"type": "integer"
},
"sequence_number": {
"description": "The sequence number of the web search call being processed.",
"type": "integer"
},
"type": {
"description": "The type of the event. Always `response.web_search_call.in_progress`.\n",
"type": "string",
"enum": [
"response.web_search_call.in_progress"
],
"x-stainless-const": true
}
},
"x-oaiMeta": {
"group": "responses",
"name": "response.web_search_call.in_progress"
}
}Fields
item_id: StringUnique ID for the output item associated with the web search call.
output_index: i64The index of the output item that the web search call is associated with.
sequence_number: i64The sequence number of the web search call being processed.
type_: ResponseWebSearchCallInProgressEventTypeThe type of the event. Always response.web_search_call.in_progress.