pub struct ToolChoiceMcp {
pub name: Option<String>,
pub server_label: String,
pub type_: ToolChoiceMcpType,
}Expand description
Use this option to force the model to call a specific tool on a remote MCP server.
JSON schema
{
"title": "MCP tool",
"description": "Use this option to force the model to call a specific tool on a remote MCP server.\n",
"type": "object",
"required": [
"server_label",
"type"
],
"properties": {
"name": {
"anyOf": [
{
"description": "The name of the tool to call on the server.\n",
"type": "string"
}
]
},
"server_label": {
"description": "The label of the MCP server to use.\n",
"type": "string"
},
"type": {
"description": "For MCP tools, the type is always `mcp`.",
"type": "string",
"enum": [
"mcp"
],
"x-stainless-const": true
}
}
}Fields
name: Option<String>server_label: StringThe label of the MCP server to use.
type_: ToolChoiceMcpTypeFor MCP tools, the type is always mcp.