pub struct ToolChoiceTypes {
pub type_: ToolChoiceTypesType,
}Expand description
Indicates that the model should use a built-in tool to generate a response. Learn more about built-in tools.
JSON schema
{
"title": "Hosted tool",
"description": "Indicates that the model should use a built-in tool to generate a response.\n[Learn more about built-in tools](/docs/guides/tools).\n",
"type": "object",
"required": [
"type"
],
"properties": {
"type": {
"description": "The type of hosted tool the model should to use. Learn more about\n[built-in tools](/docs/guides/tools).\n\nAllowed values are:\n- `file_search`\n- `web_search_preview`\n- `computer`\n- `computer_use_preview`\n- `computer_use`\n- `code_interpreter`\n- `image_generation`\n",
"type": "string",
"enum": [
"file_search",
"web_search_preview",
"computer",
"computer_use_preview",
"computer_use",
"web_search_preview_2025_03_11",
"image_generation",
"code_interpreter"
]
}
}
}Fields
type_: ToolChoiceTypesTypeThe type of hosted tool the model should to use. Learn more about built-in tools.
Allowed values are:
file_searchweb_search_previewcomputercomputer_use_previewcomputer_usecode_interpreterimage_generation