pub struct ToolSearchOutput {
pub call_id: String,
pub created_by: Option<String>,
pub execution: ToolSearchExecutionType,
pub id: String,
pub status: FunctionCallOutputStatusEnum,
pub tools: Vec<Tool>,
pub type_: ToolSearchOutputType,
}Expand description
ToolSearchOutput
JSON schema
{
"type": "object",
"required": [
"call_id",
"execution",
"id",
"status",
"tools",
"type"
],
"properties": {
"call_id": {
"anyOf": [
{
"description": "The unique ID of the tool search call generated by the model.",
"type": "string"
}
]
},
"created_by": {
"description": "The identifier of the actor that created the item.",
"type": "string"
},
"execution": {
"$ref": "#/components/schemas/ToolSearchExecutionType"
},
"id": {
"description": "The unique ID of the tool search output item.",
"type": "string"
},
"status": {
"$ref": "#/components/schemas/FunctionCallOutputStatusEnum"
},
"tools": {
"description": "The loaded tool definitions returned by tool search.",
"type": "array",
"items": {
"$ref": "#/components/schemas/Tool"
}
},
"type": {
"description": "The type of the item. Always `tool_search_output`.",
"type": "string",
"enum": [
"tool_search_output"
],
"x-stainless-const": true
}
}
}Fields
call_id: Stringcreated_by: Option<String>The identifier of the actor that created the item.
execution: ToolSearchExecutionTypeid: StringThe unique ID of the tool search output item.
status: FunctionCallOutputStatusEnumtools: Vec<Tool>The loaded tool definitions returned by tool search.
type_: ToolSearchOutputTypeThe type of the item. Always tool_search_output.