pub enum ReasoningSummary {
Auto,
Concise,
Detailed,
}Expand description
ReasoningSummary
JSON schema
{
"anyOf": [
{
"description": "A summary of the reasoning performed by the model. This can be\nuseful for debugging and understanding the model's reasoning process.\nOne of `auto`, `concise`, or `detailed`.\n\n`concise` is supported for `computer-use-preview` models and all reasoning models after `gpt-5`.\n",
"type": "string",
"enum": [
"auto",
"concise",
"detailed"
]
}
]
}Variants
Auto
A summary of the reasoning performed by the model. This can be
useful for debugging and understanding the model’s reasoning process.
One of auto, concise, or detailed.
concise is supported for computer-use-preview models and all reasoning models after gpt-5.
Concise
A summary of the reasoning performed by the model. This can be
useful for debugging and understanding the model’s reasoning process.
One of auto, concise, or detailed.
concise is supported for computer-use-preview models and all reasoning models after gpt-5.
Detailed
A summary of the reasoning performed by the model. This can be
useful for debugging and understanding the model’s reasoning process.
One of auto, concise, or detailed.
concise is supported for computer-use-preview models and all reasoning models after gpt-5.