pub enum ResponseInstructions {
String(String),
InputItemList(Vec<InputItem>),
}Expand description
A system (or developer) message inserted into the model’s context.
When using along with previous_response_id, the instructions from a previous
response will not be carried over to the next response. This makes it simple
to swap out system (or developer) messages in new responses.
JSON schema
{
"description": "A system (or developer) message inserted into the model's context.\n\nWhen using along with `previous_response_id`, the instructions from a previous\nresponse will not be carried over to the next response. This makes it simple\nto swap out system (or developer) messages in new responses.\n",
"oneOf": [
{
"description": "A text input to the model, equivalent to a text input with the\n`developer` role.\n",
"type": "string"
},
{
"title": "Input item list",
"description": "A list of one or many input items to the model, containing\ndifferent content types.\n",
"type": "array",
"items": {
"$ref": "#/components/schemas/InputItem"
}
}
]
}Variants